orion / rpms / python3x-pip

Forked from rpms/python3x-pip 2 years ago
Clone
Blob Blame History Raw
diff -up pip-19.3.1/news/7872.bugfix.pip7873 pip-19.3.1/news/7872.bugfix
--- pip-19.3.1/news/7872.bugfix.pip7873	2022-05-24 08:34:03.285054864 -0600
+++ pip-19.3.1/news/7872.bugfix	2022-05-24 08:34:03.285054864 -0600
@@ -0,0 +1 @@
+Prevent an infinite recursion with ``pip wheel`` when ``$TMPDIR`` is within the source directory.
diff -up pip-19.3.1/src/pip/_internal/operations/prepare.py.pip7873 pip-19.3.1/src/pip/_internal/operations/prepare.py
diff -up pip-19.3.1/tests/data/src/extension/extension.c.pip7873 pip-19.3.1/tests/data/src/extension/extension.c
diff -up pip-19.3.1/tests/data/src/extension/setup.py.pip7873 pip-19.3.1/tests/data/src/extension/setup.py
--- pip-19.3.1/tests/data/src/extension/setup.py.pip7873	2022-05-24 08:34:03.285054864 -0600
+++ pip-19.3.1/tests/data/src/extension/setup.py	2022-05-24 08:34:03.285054864 -0600
@@ -0,0 +1,4 @@
+from setuptools import Extension, setup
+
+module = Extension('extension', sources=['extension.c'])
+setup(name='extension', version='0.0.1', ext_modules = [module])
diff -up pip-19.3.1/tests/functional/test_wheel.py.pip7873 pip-19.3.1/tests/functional/test_wheel.py
--- pip-19.3.1/tests/functional/test_wheel.py.pip7873	2019-10-17 13:32:34.000000000 -0600
+++ pip-19.3.1/tests/functional/test_wheel.py	2022-05-24 08:34:03.285054864 -0600
@@ -1,6 +1,7 @@
 """'pip wheel' tests"""
 import os
 import re
+import sys
 from os.path import exists
 
 import pytest
@@ -228,6 +229,24 @@ def test_pip_wheel_with_user_set_in_conf
     assert "Successfully built withpyproject" in result.stdout, result.stdout
 
 
+@pytest.mark.skipif(sys.platform.startswith('win'),
+                    reason='The empty extension module does not work on Win')
+def test_pip_wheel_ext_module_with_tmpdir_inside(script, data, common_wheels):
+    tmpdir = data.src / 'extension/tmp'
+    tmpdir.mkdir()
+    script.environ['TMPDIR'] = str(tmpdir)
+
+    # To avoid a test dependency on a C compiler, we set the env vars to "noop"
+    # The .c source is empty anyway
+    script.environ['CC'] = script.environ['LDSHARED'] = str('true')
+
+    result = script.pip(
+        'wheel', data.src / 'extension',
+        '--no-index', '-f', common_wheels
+    )
+    assert "Successfully built extension" in result.stdout, result.stdout
+
+
 @pytest.mark.network
 def test_pep517_wheels_are_not_confused_with_other_files(script, tmpdir, data):
     """Check correct wheels are copied. (#6196)
diff -up pip-19.3.1/src/pip/_internal/download.py.pip7873 pip-19.3.1/src/pip/_internal/download.py
--- pip-19.3.1/src/pip/_internal/download.py.pip7873	2019-10-17 13:32:34.000000000 -0600
+++ pip-19.3.1/src/pip/_internal/download.py	2022-05-24 08:35:17.013833331 -0600
@@ -350,12 +350,24 @@ def _copy2_ignoring_special_files(src, d
 
 def _copy_source_tree(source, target):
     # type: (str, str) -> None
+    target_abspath = os.path.abspath(target)
+    target_basename = os.path.basename(target_abspath)
+    target_dirname = os.path.dirname(target_abspath)
+
     def ignore(d, names):
-        # Pulling in those directories can potentially be very slow,
-        # exclude the following directories if they appear in the top
-        # level dir (and only it).
-        # See discussion at https://github.com/pypa/pip/pull/6770
-        return ['.tox', '.nox'] if d == source else []
+        skipped = []  # type: List[str]
+        if d == source:
+            # Pulling in those directories can potentially be very slow,
+            # exclude the following directories if they appear in the top
+            # level dir (and only it).
+            # See discussion at https://github.com/pypa/pip/pull/6770
+            skipped += ['.tox', '.nox']
+        if os.path.abspath(d) == target_dirname:
+            # Prevent an infinite recursion if the target is in source.
+            # This can happen when TMPDIR is set to ${PWD}/...
+            # and we copy PWD to TMPDIR.
+            skipped += [target_basename]
+        return skipped
 
     kwargs = dict(ignore=ignore, symlinks=True)  # type: CopytreeKwargs
 